==> huaweicloudsdkeg-3.1.135-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/customize_schema_update_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CustomizeSchemaUpdateReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'description': 'str',
        'compatibility': 'str'
    }

    attribute_map = {
        'description': 'description',
        'compatibility': 'compatibility'
    }

    def __init__(self, description=None, compatibility=None):
        """CustomizeSchemaUpdateReq

        The model defined in huaweicloud sdk

        :param description: 事件模型描述
        :type description: str
        :param compatibility: 事件模型兼容性
        :type compatibility: str
        """
        
        

        self._description = None
        self._compatibility = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if compatibility is not None:
            self.compatibility = compatibility

    @property
    def description(self):
        """Gets the description of this CustomizeSchemaUpdateReq.

        事件模型描述

        :return: The description of this CustomizeSchemaUpdateReq.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CustomizeSchemaUpdateReq.

        事件模型描述

        :param description: The description of this CustomizeSchemaUpdateReq.
        :type description: str
        """
        self._description = description

    @property
    def compatibility(self):
        """Gets the compatibility of this CustomizeSchemaUpdateReq.

        事件模型兼容性

        :return: The compatibility of this CustomizeSchemaUpdateReq.
        :rtype: str
        """
        return self._compatibility

    @compatibility.setter
    def compatibility(self, compatibility):
        """Sets the compatibility of this CustomizeSchemaUpdateReq.

        事件模型兼容性

        :param compatibility: The compatibility of this CustomizeSchemaUpdateReq.
        :type compatibility: str
        """
        self._compatibility = compatibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomizeSchemaUpdateReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeg-3.1.159-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/customize_schema_update_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CustomizeSchemaUpdateReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'description': 'str',
        'compatibility': 'str'
    }

    attribute_map = {
        'description': 'description',
        'compatibility': 'compatibility'
    }

    def __init__(self, description=None, compatibility=None):
        r"""CustomizeSchemaUpdateReq

        The model defined in huaweicloud sdk

        :param description: 事件模型描述
        :type description: str
        :param compatibility: 事件模型兼容性
        :type compatibility: str
        """
        
        

        self._description = None
        self._compatibility = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if compatibility is not None:
            self.compatibility = compatibility

    @property
    def description(self):
        r"""Gets the description of this CustomizeSchemaUpdateReq.

        事件模型描述

        :return: The description of this CustomizeSchemaUpdateReq.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        r"""Sets the description of this CustomizeSchemaUpdateReq.

        事件模型描述

        :param description: The description of this CustomizeSchemaUpdateReq.
        :type description: str
        """
        self._description = description

    @property
    def compatibility(self):
        r"""Gets the compatibility of this CustomizeSchemaUpdateReq.

        事件模型兼容性

        :return: The compatibility of this CustomizeSchemaUpdateReq.
        :rtype: str
        """
        return self._compatibility

    @compatibility.setter
    def compatibility(self, compatibility):
        r"""Sets the compatibility of this CustomizeSchemaUpdateReq.

        事件模型兼容性

        :param compatibility: The compatibility of this CustomizeSchemaUpdateReq.
        :type compatibility: str
        """
        self._compatibility = compatibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomizeSchemaUpdateReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
